@@ -4,6 +4,10 @@
 #'
 #' @param app Choose the app to run. Either "base", "quant", or "marketing". "marketing" is the default
 #'
+#' @examples
+#' if (interactive()) {
+#'   radiant()
+#' }
 #' @export
 radiant <- function(app = c("marketing", "quant", "base")) {
 
@@ -18,7 +22,7 @@ radiant <- function(app = c("marketing", "quant", "base")) {
   runApp(system.file(app[1], package='radiant'))
 }
 
-#' Alias used to set the class for output from an analysis function in R/ (e.g., single_mean)
+#' Alias used to set the class for analysis function return
 #'
 #' @examples
 #' foo <- function(x) x^2 %>% set_class(c("foo", class(.)))
@@ -28,6 +32,8 @@ set_class <- `class<-`
 
 #' Add stars '***' to a data.frame (from broom's `tidy` function) based on p.values
 #'
+#' @details Add stars to output from broom's `tidy` function
+#'
 #' @param pval Vector of p-values
 #'
 #' @return A vector of stars
@@ -42,7 +48,9 @@ sig_stars <- function(pval) {
     c("",".","*", "**", "***")[.]
 }
 
-#' Hide warnings and messages from app user (e.g., ggplot2). Adapted from http://www.onthelambda.com/2014/09/17/fun-with-rprofile-and-customizing-r-startup/
+#' Hide warnings and messages and return invisible
+#'
+#' @details Adapted from \url{http://www.onthelambda.com/2014/09/17/fun-with-rprofile-and-customizing-r-startup/}
 #'
 #' @param ... Inputs to keep quite
 #'
@@ -55,7 +63,9 @@ sshh <- function(...) {
   invisible()
 }
 
-#' Hide warnings and messages from app user (e.g., ggplot2). Adapted from http://www.onthelambda.com/2014/09/17/fun-with-rprofile-and-customizing-r-startup/
+#' Hide warnings and messages and return result
+#'
+#' @details Adapted from \url{http://www.onthelambda.com/2014/09/17/fun-with-rprofile-and-customizing-r-startup/}
 #'
 #' @param ... Inputs to keep quite
 #'
@@ -67,7 +77,7 @@ sshhr <- function(...) {
   suppressWarnings( suppressMessages( ... ) )
 }
 
-#' Get data for analysis functions exported by Radiant
+#' Get data for analysis functions
 #'
 #' @param dataset Name of the dataframe
 #' @param vars Variables to extract from the dataframe
@@ -77,8 +87,17 @@ sshhr <- function(...) {
 #'
 #' @return Data.frame with specified columns and rows
 #'
+#' @examples
+#' r_data <- list()
+#' r_data$dat <- mtcars
+#' getdata("dat","mpg:vs", filt = "mpg > 20", slice = "1:5")
+#'
 #' @export
-getdata <- function(dataset, vars = "", na.rm = TRUE, filt = "", slice = "") {
+getdata <- function(dataset,
+                    vars = "",
+                    na.rm = TRUE,
+                    filt = "",
+                    slice = "") {
 
   filt %<>% gsub("\\s","", .)
 
@@ -89,7 +108,7 @@ getdata <- function(dataset, vars = "", na.rm = TRUE, filt = "", slice = "") {
       r_data[[dataset]]
     } else if(exists(dataset)) {
       d_env <- pryr::where(dataset)
-      # cat("Dataset", dataset, "loaded from", attr(d_env,"name"), "environment\n")
+      # cat("Dataset", dataset, "loaded from", environmentName(d_env), "environment\n")
       d_env[[dataset]]
     } else {
       paste0("Dataset ", dataset, " is not available. Please load the dataset and use the name in the function call") %>%
@@ -101,7 +120,7 @@ getdata <- function(dataset, vars = "", na.rm = TRUE, filt = "", slice = "") {
         { if(na.rm) { if(anyNA(.)) na.omit(.) else . } }
 }
 
-#' Change data function exported by Radiant
+#' Change data
 #'
 #' @param dataset Name of the dataframe to change
 #' @param vars New variables to add to the data.frame
@@ -109,20 +128,30 @@ getdata <- function(dataset, vars = "", na.rm = TRUE, filt = "", slice = "") {
 #'
 #' @return None
 #'
+#' @examples
+#' \dontrun{
+#' r_data <- list()
+#' r_data$dat <- data.frame(a = 1:20)
+#' changedata("dat",20:1, "b")
+#' head(r_data$dat)
+#' }
+#'
 #' @export
-changedata <- function(dataset, vars = c(), var_names = names(vars)) {
-
-  r_env <- r_data <- NULL
+changedata <- function(dataset,
+                       vars = c(),
+                       var_names = names(vars)) {
 
   if(exists("r_env")) {
     cat("Dataset", dataset, "changed in r_env\n")
-    r_env$r_data[[dataset]][,var_names] <<- vars
+    # r_env$r_data[[dataset]][,var_names] <<- vars
+    r_env$r_data[[dataset]][,var_names] <- vars
   } else if(exists("r_data") && !is.null(r_data[[dataset]])) {
     if(exists("running_local")) { if(running_local) cat("Dataset", dataset, "changed in r_data list\n") }
-    r_data[[dataset]][,var_names] <<- vars
+    d_env <- pryr::where("r_data")
+    d_env$r_data[[dataset]][,var_names] <- vars
   } else if(exists(dataset)) {
     d_env <- pryr::where(dataset)
-    cat("Dataset", dataset, "changed in", attr(d_env,"name"), "environment\n")
+    cat("Dataset", dataset, "changed in", environmentName(d_env), "environment\n")
     d_env[[dataset]][,var_names] <- vars
   } else {
     paste0("Dataset ", dataset, " is not available. Please load the dataset and use the name in the function call") %>%
@@ -137,14 +166,26 @@ changedata <- function(dataset, vars = c(), var_names = names(vars)) {
 
 #' Create a launcher for Windows (.bat)
 #'
+#' @details On Windows a file named `radiant.bat` will be put on the desktop. Double-click the file to launch the specified Radiant app
+#'
 #' @param app App to run when the desktop icon is double-clicked ("marketing", "quant", or "base"). Default is "marketing"
 #'
-#' @return On Windows a file named `radiant.bat` will be put on the desktop. Double-click the file to launch the specified Radiant app
+#' @examples
+#' if (interactive()) {
+#'   if(Sys.info()["sysname"] != "Windows") {
+#'     win_launcher()
+#'     fn <- paste0(Sys.getenv("USERPROFILE") ,"/Desktop/radiant.bat")
+#'     if(!file.exists(fn))
+#'        stop("Windows launcher not created")
+#'     else
+#'       unlink(fn)
+#'   }
+#' }
 #'
 #' @export
 win_launcher <- function(app = c("marketing", "quant", "base")) {
 
-  if(.Platform$OS.type != 'windows')
+  if(Sys.info()["sysname"] != "Windows")
     return("This function is for Windows only. For Mac use the mac_launcher() function")
 
   local_dir <- Sys.getenv("R_LIBS_USER")
@@ -155,11 +196,23 @@ win_launcher <- function(app = c("marketing", "quant", "base")) {
   cat(launch_string,file=paste0(filepath,"radiant.bat"),sep="\n")
 }
 
-#' Create a launcher for Windows (.command)
+#' Create a launcher for Mac (.command)
+#'
+#' @details On Mac a file named `radiant.command` will be put on the desktop. Double-click the file to launch the specified Radiant app
 #'
 #' @param app App to run when the desktop icon is double-clicked ("marketing", "quant", or "base"). Default is "marketing"
 #'
-#' @return On Mac a file named `radiant.command` will be put on the desktop. Double-click the file to launch the specified Radiant app
+#' @examples
+#' if (interactive()) {
+#'   if(Sys.info()["sysname"] != "Darwin") {
+#'     mac_launcher()
+#'     fn <- paste0("/Users/",Sys.getenv("USER"),"/Desktop/radiant.command")
+#'     if(!file.exists(fn))
+#'        stop("Mac launcher not created")
+#'     else
+#'       unlink(fn)
+#'   }
+#' }
 #'
 #' @export
 mac_launcher <- function(app = c("marketing", "quant", "base")) {
